run method

  1. @override
Future<void> run()
override

Runs this command.

The return value is wrapped in a Future if necessary and returned by CommandRunner.runCommand.

Implementation

@override
Future<void> run() async {
  try {
    await ConfigService.showConfig();

    Logger.phase('Tips & Shortcuts');
    Logger.info('• Run "udara_cli setup" to modify CLI settings.');
    Logger.info(
        '• Use the --slack-channel parameter during builds to override the default channel.');
    Logger.info(
        '• Run "udara_cli setup --reset" to clear all stored CLI configuration.');
  } on BuildException catch (e, s) {
    Logger.error(e.message,
        cause: e.fix, stackTrace: e.originalStackTrace ?? s);
    rethrow;
  } catch (e, s) {
    Logger.error('An unexpected error occurred while reading configuration.',
        cause: e, stackTrace: s);
    rethrow;
  }
}