core/services/hooks_service library

Classes

HookContext
What a hook is told about the current run, exposed as UDARA_* environment variables.
HooksService
Loads and runs project hooks declared in udara.yaml:

Enums

HookPoint
Points in the pipeline where user commands from udara.yaml run.