HookContext class

What a hook is told about the current run, exposed as UDARA_* environment variables.

Constructors

HookContext({required String command, required String projectDir, required String client, required File envFile, required bool isTest, String? platform, String? buildType, String? version, String? bundleId, String? appName, String? artifact})

Properties

appName → String?
final
artifact → String?
final
buildType → String?
final
bundleId → String?
final
client → String
final
command → String
final
envFile → File
final
hashCode → int
The hash code for this object.
no setterinherited
isTest → bool
final
platform → String?
final
projectDir → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toEnvironment(HookPoint point) → Map<String, String>
toString() → String
A string representation of this object.
inherited
withArtifact(String? path) → HookContext

Operators

operator ==(Object other) → bool
The equality operator.
inherited