SlackService class

Constructors

SlackService({required String botToken, required String channel, bool debugMode = false})

Properties

botToken → String
final
channel → String
final
debugMode → bool
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendBuildStepNotification({required String step, required String client, required String platform, required String status, String? additionalInfo, String? errorMessage}) → Future<void>
Send build step notification
sendBuildSummary({required String client, required String platform, required String type, required String version, required bool success, required Duration buildTime, String? errorMessage, File? artifactFile}) → Future<void>
Send build completion summary, then upload the APK when there is one.
sendMessage(String message, {String? emoji}) → Future<bool>
Send a simple text message to Slack
sendRichMessage({required String title, required String message, String color = 'good', Map<String, String>? fields, String? emoji}) → Future<bool>
Send a rich message with attachments/blocks
testConnection() → Future<bool>
Test the Slack connection with detailed feedback
toString() → String
A string representation of this object.
inherited
uploadFile({required File file, String? title, String? comment}) → Future<bool>
Upload a file to Slack using the three-step external upload process

Operators

operator ==(Object other) → bool
The equality operator.
inherited