CleanupService class

Constructors

CleanupService({required String projectDir, required ConfigService config})

Properties

config → ConfigService
final
hashCode → int
The hash code for this object.
no setterinherited
projectDir → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
performFullCleanup() → Future<void>
Reverts all temporary changes made during the build process: restores backed-up files, removes files the CLI generated, deletes managed branding folders and puts the original fonts back.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited