WhiteLabelCommand constructor
WhiteLabelCommand()
Implementation
WhiteLabelCommand() {
argParser
..addOption(
'client',
abbr: 'c',
mandatory: true,
help: 'The name of the client to whitelabel the project as.',
)
..addFlag(
'test',
negatable: false,
help: 'Use the test environment (.env_test).',
)
..addFlag(
'keep',
abbr: 'k',
negatable: false,
help: 'Leave the root .env, branding assets and pubspec changes in '
'place so the app can be run as this client '
'(flutter run --dart-define=CLIENT_ENV=.env). '
'Without it they are restored once the native branding is applied.',
)
..addFlag(
'slack',
negatable: false,
help: 'Send Slack notifications during the process.',
)
..addOption(
'slack-channel',
help:
'Slack channel for notifications (e.g., #builds, @username). Defaults to #builds',
defaultsTo: '#builds',
);
}